@@ -1,53 +1,20 @@
 /*
 
- ============================================================================
-                   The Apache Software License, Version 1.1
- ============================================================================
+   Copyright 2001,2003  The Apache Software Foundation 
 
- Copyright (C) 1999-2003 The Apache Software Foundation. All rights reserved.
+   Licensed under the Apache License, Version 2.0 (the "License");
+   you may not use this file except in compliance with the License.
+   You may obtain a copy of the License at
 
- Redistribution and use in source and binary forms, with or without modifica-
- tion, are permitted provided that the following conditions are met:
+       http://www.apache.org/licenses/LICENSE-2.0
 
- 1. Redistributions of  source code must  retain the above copyright  notice,
-    this list of conditions and the following disclaimer.
-
- 2. Redistributions in binary form must reproduce the above copyright notice,
-    this list of conditions and the following disclaimer in the documentation
-    and/or other materials provided with the distribution.
-
- 3. The end-user documentation included with the redistribution, if any, must
-    include  the following  acknowledgment:  "This product includes  software
-    developed  by the  Apache Software Foundation  (http://www.apache.org/)."
-    Alternately, this  acknowledgment may  appear in the software itself,  if
-    and wherever such third-party acknowledgments normally appear.
-
- 4. The names "Batik" and  "Apache Software Foundation" must  not  be
-    used to  endorse or promote  products derived from  this software without
-    prior written permission. For written permission, please contact
-    apache@apache.org.
-
- 5. Products  derived from this software may not  be called "Apache", nor may
-    "Apache" appear  in their name,  without prior written permission  of the
-    Apache Software Foundation.
-
- THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED WARRANTIES,
- INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND
- FITNESS  FOR A PARTICULAR  PURPOSE ARE  DISCLAIMED.  IN NO  EVENT SHALL  THE
- APACHE SOFTWARE  FOUNDATION  OR ITS CONTRIBUTORS  BE LIABLE FOR  ANY DIRECT,
- INDIRECT, INCIDENTAL, SPECIAL,  EXEMPLARY, OR CONSEQUENTIAL  DAMAGES (INCLU-
- DING, BUT NOT LIMITED TO, PROCUREMENT  OF SUBSTITUTE GOODS OR SERVICES; LOSS
- OF USE, DATA, OR  PROFITS; OR BUSINESS  INTERRUPTION)  HOWEVER CAUSED AND ON
- ANY  THEORY OF LIABILITY,  WHETHER  IN CONTRACT,  STRICT LIABILITY,  OR TORT
- (INCLUDING  NEGLIGENCE OR  OTHERWISE) ARISING IN  ANY WAY OUT OF THE  USE OF
- THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
- This software  consists of voluntary contributions made  by many individuals
- on  behalf of the Apache Software  Foundation. For more  information on the
- Apache Software Foundation, please see <http://www.apache.org/>.
-
-*/
+   Unless required by applicable law or agreed to in writing, software
+   distributed under the License is distributed on an "AS IS" BASIS,
+   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+   See the License for the specific language governing permissions and
+   limitations under the License.
 
+ */
 package org.apache.batik.util.gui;
 
 import java.awt.BorderLayout;
@@ -94,7 +61,7 @@ import org.apache.batik.util.gui.resource.ResourceManager;
  * This class represents a panel to edit/add/remove CSS media.
  *
  * @author <a href="mailto:tkormann@apache.org">Thierry Kormann</a>
- * @version $Id: CSSMediaPanel.java,v 1.4 2003/08/09 16:58:44 deweese Exp $
+ * @version $Id: CSSMediaPanel.java,v 1.6 2004/10/30 16:54:54 deweese Exp $
  */
 public class CSSMediaPanel extends JPanel implements ActionMap {
 
@@ -239,9 +206,9 @@ public class CSSMediaPanel extends JPanel implements ActionMap {
      */
     public List getMedia() {
 	List media = new ArrayList(listModel.size());
-	Enumeration enum = listModel.elements();
-	while (enum.hasMoreElements()) {
-	    media.add(enum.nextElement());
+	Enumeration e = listModel.elements();
+	while (e.hasMoreElements()) {
+	    media.add(e.nextElement());
 	}
 	return media;
     }
@@ -251,9 +218,9 @@ public class CSSMediaPanel extends JPanel implements ActionMap {
      */
     public String getMediaAsString() {
 	StringBuffer buffer = new StringBuffer();
-	Enumeration enum = listModel.elements();
-	while (enum.hasMoreElements()) {
-	    buffer.append((String)enum.nextElement());
+	Enumeration e = listModel.elements();
+	while (e.hasMoreElements()) {
+	    buffer.append((String)e.nextElement());
 	    buffer.append(" ");
 	}
 	return buffer.toString();
